@@ -153,9 +153,9 @@ class Column(object):
         grid_cls_cols = grid_locals.setdefault('__cls_cols__', [])
         grid_cls_cols.append(self)
 
-    def __init__(self, label, key=None, filter=None, can_sort=True,
+    def __init__(self, label, key=None, filter=None, can_sort=True,  # noqa: C901
                  xls_width=None, xls_style=None, xls_num_format=None,
-                 render_in=_None, has_subtotal=False, visible=True, **kwargs):
+                 render_in=_None, has_subtotal=False, visible=True, group=None, **kwargs):
         self.label = label
         self.key = key
         self.filter = filter
@@ -177,6 +177,16 @@ class Column(object):
         if xls_style:
             self.xls_style = xls_style
 
+        try:
+            is_group_cls = issubclass(type(group), ColumnGroup) or issubclass(group, ColumnGroup)
+        except TypeError:
+            is_group_cls = False
+
+        if group is not None and not is_group_cls:
+            raise ValueError(_('expected group to be a subclass of ColumnGroup'))
+
+        self.group = group
+
         # if the key isn't a base string, assume its a column-like object that
         # works with a SA Query instance
         if key is None:
@@ -202,7 +212,7 @@ class Column(object):
 
     def new_instance(self, grid):
         cls = self.__class__
-        column = cls(self.label, self.key, None, self.can_sort, _dont_assign=True)
+        column = cls(self.label, self.key, None, self.can_sort, group=self.group, _dont_assign=True)
         column.grid = grid
         column.expr = self.expr
 
@@ -331,10 +341,10 @@ class LinkColumnBase(Column):
 
     def __init__(self, label, key=None, filter=None, can_sort=True,
                  link_label=None, xls_width=None, xls_style=None, xls_num_format=None,
-                 render_in=_None, has_subtotal=False, visible=True, **kwargs):
+                 render_in=_None, has_subtotal=False, visible=True, group=None, **kwargs):
         super().__init__(label, key, filter, can_sort, xls_width,
                          xls_style, xls_num_format, render_in,
-                         has_subtotal, visible, **kwargs)
+                         has_subtotal, visible, group=group, **kwargs)
         self.link_label = link_label
 
     def render_html(self, record, hah):
@@ -354,10 +364,10 @@ class BoolColumn(Column):
     def __init__(self, label, key_or_filter=None, key=None, can_sort=True,
                  reverse=False, true_label=_('True'), false_label=_('False'),
                  xls_width=None, xls_style=None, xls_num_format=None,
-                 render_in=_None, has_subtotal=False, visible=True, **kwargs):
+                 render_in=_None, has_subtotal=False, visible=True, group=None, **kwargs):
         super().__init__(label, key_or_filter, key, can_sort, xls_width,
                          xls_style, xls_num_format, render_in,
-                         has_subtotal, visible, **kwargs)
+                         has_subtotal, visible, group=group, **kwargs)
         self.reverse = reverse
         self.true_label = true_label
         self.false_label = false_label
@@ -374,20 +384,20 @@ class YesNoColumn(BoolColumn):
 
     def __init__(self, label, key_or_filter=None, key=None, can_sort=True,
                  reverse=False, xls_width=None, xls_style=None, xls_num_format=None,
-                 render_in=_None, has_subtotal=False, visible=True, **kwargs):
+                 render_in=_None, has_subtotal=False, visible=True, group=None, **kwargs):
         super().__init__(label, key_or_filter, key, can_sort, reverse,
                          _('Yes'), _('No'), xls_width, xls_style, xls_num_format,
-                         render_in, has_subtotal, visible, **kwargs)
+                         render_in, has_subtotal, visible, group=group, **kwargs)
 
 
 class DateColumnBase(Column):
 
     def __init__(self, label, key_or_filter=None, key=None, can_sort=True,
                  html_format=None, xls_width=None, xls_style=None, xls_num_format=None,
-                 render_in=_None, has_subtotal=False, visible=True, **kwargs):
+                 render_in=_None, has_subtotal=False, visible=True, group=None, **kwargs):
         super().__init__(label, key_or_filter, key, can_sort, xls_width,
                          xls_style, xls_num_format, render_in, has_subtotal,
-                         visible, **kwargs)
+                         visible, group=group, **kwargs)
         if html_format:
             self.html_format = html_format
 
@@ -469,10 +479,10 @@ class NumericColumn(Column):
                  reverse=False, xls_width=None, xls_style=None, xls_num_format=None,
                  render_in=_None, format_as='general', places=2, curr='',
                  sep=',', dp='.', pos='', neg='-', trailneg='',
-                 xls_neg_red=True, has_subtotal=False, visible=True, **kwargs):
+                 xls_neg_red=True, has_subtotal=False, visible=True, group=None, **kwargs):
         super().__init__(label, key_or_filter, key, can_sort, xls_width,
                          xls_style, xls_num_format, render_in,
-                         has_subtotal, visible, **kwargs)
+                         has_subtotal, visible, group=group, **kwargs)
         self.places = places
         self.curr = curr
         self.sep = sep
@@ -550,6 +560,15 @@ class EnumColumn(Column):
         return value.value
 
 
+class ColumnGroup(object):
+    label = None
+    class_ = None
+
+    def __init__(self, label, class_=None):
+        self.label = label
+        self.class_ = class_
+
+
 class BaseGrid(six.with_metaclass(_DeclarativeMeta, object)):
     __cls_cols__ = ()
     identifier = None
@@ -926,7 +945,10 @@ class BaseGrid(six.with_metaclass(_DeclarativeMeta, object)):
                 self.session_key
             )
             session_override = self.args_have_session_override(args)
-            if not self.args_have_op(args) or session_override:
+            # apply arg indicates that filtering/paging/sorting form was submitted
+            apply = self.prefix_qs_arg_key('apply') in args
+            args.pop(self.prefix_qs_arg_key('apply'), None)
+            if (not self.args_have_op(args) and not apply) or session_override:
                 session_args = self.get_session_store(args, session_override)
                 # override paging if it exists in the query
                 if self.args_have_page(args):
